package cn.com.qmth.examcloud.core.oe.admin.dao.entity;

import javax.persistence.*;
import javax.validation.constraints.NotNull;

import cn.com.qmth.examcloud.web.jpa.JpaEntity;

/**
 * @author chenken
 * @date 2018年8月13日 上午11:06:58
 * @company QMTH
 * @description 考生信息表
 */
@Entity
@Table(name = "ec_oe_exam_student",indexes = {
        @Index(name = "IDX_E_O_E_S_001",columnList = "examStudentId",unique = true),
        @Index(name = "IDX_E_O_E_S_002",columnList = "studentId"),
        @Index(name = "IDX_E_O_E_S_003",columnList = "identityNumber"),
        @Index(name = "IDX_E_O_E_S_004",columnList = "studentCode"),
        @Index(name = "IDX_E_O_E_S_005",columnList = "examId"),
        @Index(name = "IDX_E_O_E_S_006",columnList = "courseId")
})
public class ExamStudentEntity extends JpaEntity {
    private static final long serialVersionUID = -4647126917276922968L;

    /**
     * 注意:仅作主键使用,不跟其他表关联,不参与任何业务计算
     * 业务计算使用 examStudentId
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;
    /**
     * 考生ID(与考务的考生ID一致)
     * 跟其他表关联使用
     */
    @NotNull
    private Long examStudentId;
    /**
     * 考试ID
     */
    @NotNull
    private Long examId;
    /**
     * 学生ID
     */
    @NotNull
    private Long studentId;
    /**
     * 学号
     */
    @Column(length = 50)
    private String studentCode;
    /**
     * 学生姓名
     */
    @Column(length = 20)
    private String studentName;
    /**
     * 身份证号
     */
    @Column(length = 20)
    private String identityNumber;
    /**
     * 课程ID
     */
    @NotNull
    private Long courseId;
    /**
     * 课程Code
     */
    @Column(length = 20)
    private String courseCode;
    /**
     * 课程层次
     */
    private String courseLevel;

    /**
     * 学习中心ID
     */
    private Long orgId;

    /**
     * 顶级机构ID
     */
    private Long rootOrgId;
    /**
     * 专业code
     */
    @Column(length = 20)
    private String specialtyCode;
    /**
     * 专业名称
     */
    @Column(length = 20)
    private String specialtyName;
    /**
     * 试卷类型
     */
    @Column(length = 20)
    private String paperType;
    /**
     * 采集人
     */
    @Column(length = 200)
    private String infoCollector;
    /**
     * 是否完成考试
     */
    private Boolean finished;
    /**
     * 正常考试次数
     */
    private Integer normalExamTimes;
    /**
     * 是否重考
     */
    @Column(name = "is_reexamine")
    private Boolean isReExamine;
    /**
     * 重考是否已完成
     */
    @Column(name = "reexamine_completed")
    private Boolean reExamineCompleted;
    
    /**
     * 年级
     */
    @Column(name = "grade",length = 50)
    private String grade;
    /**
	 * 是否可用
	 */
    @Column(name = "enable")
    private Boolean enable;
    
    //private String orgCode;
    //private String orgName;
    //private String courseName;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getExamStudentId() {
        return examStudentId;
    }

    public void setExamStudentId(Long examStudentId) {
        this.examStudentId = examStudentId;
    }

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public Long getStudentId() {
        return studentId;
    }

    public void setStudentId(Long studentId) {
        this.studentId = studentId;
    }

    public String getStudentCode() {
        return studentCode;
    }

    public void setStudentCode(String studentCode) {
        this.studentCode = studentCode;
    }

    public String getStudentName() {
        return studentName;
    }

    public void setStudentName(String studentName) {
        this.studentName = studentName;
    }

    public String getIdentityNumber() {
        return identityNumber;
    }

    public void setIdentityNumber(String identityNumber) {
        this.identityNumber = identityNumber;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public String getCourseCode() {
        return courseCode;
    }

    public void setCourseCode(String courseCode) {
        this.courseCode = courseCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getRootOrgId() {
        return rootOrgId;
    }

    public void setRootOrgId(Long rootOrgId) {
        this.rootOrgId = rootOrgId;
    }

    public String getSpecialtyCode() {
        return specialtyCode;
    }

    public void setSpecialtyCode(String specialtyCode) {
        this.specialtyCode = specialtyCode;
    }

    public String getSpecialtyName() {
        return specialtyName;
    }

    public void setSpecialtyName(String specialtyName) {
        this.specialtyName = specialtyName;
    }

    public String getPaperType() {
        return paperType;
    }

    public void setPaperType(String paperType) {
        this.paperType = paperType;
    }

    public String getInfoCollector() {
        return infoCollector;
    }

    public void setInfoCollector(String infoCollector) {
        this.infoCollector = infoCollector;
    }

    public Boolean getFinished() {
        return finished;
    }

    public void setFinished(Boolean finished) {
        this.finished = finished;
    }

    public Integer getNormalExamTimes() {
        return normalExamTimes;
    }

    public void setNormalExamTimes(Integer normalExamTimes) {
        this.normalExamTimes = normalExamTimes;
    }

    public Boolean getIsReExamine() {
		return isReExamine;
	}

	public void setIsReExamine(Boolean isReExamine) {
		this.isReExamine = isReExamine;
	}

	public Boolean getReExamineCompleted() {
        return reExamineCompleted;
    }

    public void setReExamineCompleted(Boolean reExamineCompleted) {
        this.reExamineCompleted = reExamineCompleted;
    }

	public String getCourseLevel() {
		return courseLevel;
	}

	public void setCourseLevel(String courseLevel) {
		this.courseLevel = courseLevel;
	}

	public String getGrade() {
		return grade;
	}

	public void setGrade(String grade) {
		this.grade = grade;
	}

	public Boolean getEnable() {
		return enable;
	}

	public void setEnable(Boolean enable) {
		this.enable = enable;
	}
    
}